@@ -1,6 +1,6 @@
 package Term::ANSIColor::Concise;
 
-our $VERSION = "2.02";
+our $VERSION = "2.0201";
 
 use v5.14;
 use warnings;
@@ -362,9 +362,9 @@ sub apply_color {
 	my($s, $e, $el) = @{ $cache->{$color} //= [ ansi_pair($color) ] };
 	state $reset = qr{ \e\[[0;]*m (?: \e\[[0;]*[Km] )* }x;
 	if ($el) {
-	    $text =~ s/(\A|(?<=[\n\r])|$reset)([^\e\r\n]*)/${1}${s}${2}${e}/mg;
+	    $text =~ s/(\A|(?<=[\r\n])|$reset)([^\e\r\n]*)/${1}${s}${2}${e}/mg;
 	} else {
-	    $text =~ s/(\A|(?<=[\r\r])|$reset)([^\e\r\n]+)/${1}${s}${2}${e}/mg;
+	    $text =~ s/(\A|(?<=[\r\n])|$reset)([^\e\r\n]+)/${1}${s}${2}${e}/mg;
 	}
 	return $text;
     }
@@ -401,7 +401,7 @@ Term::ANSIColor::Concise - Produce ANSI terminal sequence by concise notation
 
 =head1 VERSION
 
-Version 2.02
+Version 2.0201
 
 
 =head1 DESCRIPTION
